@@ -205,9 +205,7 @@ class Main:
         except:
             #print(e)
             excep = traceback.format_exc()
-            print(excep)
             excepLine = excep.split("\n")[3][excep.split("\n")[3].find("line") + 5:]
-            print(excepLine)
             lineNum = int(excepLine) - 3
             withoutThisFile = excep.split("\n")[0] + "\n" + "\n" + excep.split("\n")[3][:excep.split("\n")[3].find("line") + 5] + str(lineNum) + "\n" + "\n".join(excep.split("\n")[4:])
             print("\n" + withoutThisFile.replace('"<string>"', self.filePath))
